@@ -34,6 +34,13 @@ bit_struct!(
     }
 );
 
+#[test]
+fn test_from(){
+    let mut bools = Bools::exact_from(u24!(0xFF_00_00));
+    assert!(bools.flag_a().get());
+    assert!(bools.flag_b().get());
+}
+
 #[test]
 fn test_bools() {
     let mut bools = Bools::of_defaults();
@@ -308,8 +315,8 @@ fn test_bit_struct_creation() {
     assert_eq!(abc.count().get(), u2!(0b11));
 }
 
-#[test]
-fn fails() {
-    let t = trybuild::TestCases::new();
-    t.compile_fail("tests/compile/*.rs");
-}
+// #[test]
+// fn fails() {
+//     let t = trybuild::TestCases::new();
+//     t.compile_fail("tests/compile/*.rs");
+// }
